summaryrefslogtreecommitdiff
path: root/cui/source/options/optchart.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'cui/source/options/optchart.hxx')
-rw-r--r--cui/source/options/optchart.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/cui/source/options/optchart.hxx b/cui/source/options/optchart.hxx
index 1b457dd64385..1b2d528e59df 100644
--- a/cui/source/options/optchart.hxx
+++ b/cui/source/options/optchart.hxx
@@ -38,7 +38,7 @@
#include <svx/dlgctrl.hxx>
// header for PushButton
#include <vcl/button.hxx>
// header for XColorTable
#include <svx/xtable.hxx>
#include "cfgchart.hxx"
@@ -67,7 +67,7 @@ private:
SvxChartOptions* pChartOptions;
SvxChartColorTableItem* pColorConfig;
- XColorTable* pColorTab;
+ XColorList* pColorTab;
DECL_LINK( ResetToDefaults, void * );
DECL_LINK( AddChartColor, void * );
@@ -38,7 +38,7 @@
// header for PushButton
#include <vcl/button.hxx>
-// header for XColorTable
+// header for XColorList
#include <svx/xtable.hxx>
#include "cfgchart.hxx"